<?xml version="1.0" encoding="UTF-8"?>
<!-- VZ809v1.0_VALXSLT_550u2, 02-06-2021 -->
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:vbt="http://ei.vektis.nl/vz/basis/v1_0"
xmlns:vz809="http://ei.vektis.nl/vz/vz809/v1_0"
xmlns:vz810="http://ei.vektis.nl/vz/vz810/v1_0" >


 	<xsl:import href="rc0350.xslt"/>
 	<xsl:import href="rc8028.xslt"/> 
 	<xsl:import href="rc8986.xslt"/>
	<xsl:import href="rc9196.xslt"/>	
	<xsl:import href="rc9203a.xslt"/>	
	<xsl:import href="rc9204a.xslt"/>
	<xsl:import href="rc9205a.xslt"/>	
	<xsl:import href="rc9207.xslt"/>	
	<xsl:import href="rc9208.xslt"/>

 	
	<!-- Uitvoer is vz810 bericht met Retourcodes. -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" />
	
	<xsl:variable name="Berichtcode" select="//vz809:Bericht/vz809:Header/vbt:Berichtcode" />
	<xsl:variable name="BerichtSoort" select="//vz809:Bericht/vz809:Header/vbt:BerichtSoort"/> 
	<xsl:variable name="Verzenddatum" select="translate(//vz809:Bericht/vz809:Header/vbt:Verzenddatum, '-', '')"/>
	<xsl:variable name="AntwoordBetwistingscode" select="//vz809:Bericht/vz809:Specificatieregel/vz809:Details/vz809:AntwoordBetwistingscode"/>
	<xsl:variable name="DatumAntwoordBetwistingscode" select="translate(//vz809:Bericht/vz809:Specificatieregel/vz809:Details/vz809:AanvullendeInfo/vz809:DatumAntwoordBetwistingscode, '-', '')"/>
	<xsl:variable name="Overig" select="//vz809:Bericht/vz809:Specificatieregel/vz809:Details/vz809:AanvullendeInfo/vz809:Overig"/>	

	<!-- Controleer op errors in de Header -->
	<!-- retourcode 8028: Soort bericht ontbreekt of is onjuist -->
	<xsl:variable name="rc8028">
		<xsl:call-template name="rc8028">
			<xsl:with-param name="BerichtSoort" select="$BerichtSoort" />
		</xsl:call-template>
	</xsl:variable>

	<!-- retourcode 8986: Verzenddatum moet kleiner zijn dan of gelijk zijn aan de huidige datum. -->
	<xsl:variable name="rc8986">
		<xsl:call-template name="rc8986">
			<xsl:with-param name="Verzenddatum" select="$Verzenddatum" />
			<xsl:with-param name="BerichtSoort" select="$BerichtSoort" />
		</xsl:call-template>
	</xsl:variable>

	<xsl:template match="//vz809:Bericht">
		<vz810:Bericht>
			<xsl:attribute name="xsi:schemaLocation">http://ei.vektis.nl/vz/vz810/v1_0 vz810_551.xsd</xsl:attribute>
			
			<xsl:choose>
				<!-- Geen errors in de Header, dan hele bericht als retour -->
				<xsl:when test="$rc8028='' and $rc8986=''">
					<xsl:apply-templates select="vz809:Header"/>
					<xsl:apply-templates select="vz809:Context"/>
					<xsl:apply-templates select="vz809:Specificatieregel"/>  
  				</xsl:when>

				<!-- Wel errors in de Header, dan alleen Header als retour -->
				<xsl:otherwise>
					<xsl:apply-templates select="vz809:Header"/>
				</xsl:otherwise>
			</xsl:choose>
				
		</vz810:Bericht>
	</xsl:template>	
		
	<xsl:template match="vz809:Header">
		<vz810:Header>
		
			<xsl:apply-templates select="vbt:BerichtSoort" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:CrediteurOrgaan"/>
			<xsl:apply-templates select="vbt:BuitenlandsVerbindingsOrgaan"/>
			<xsl:apply-templates select="vbt:Verzenddatum" mode="copy-if-exists"/>
			<vz810:BerichtCode>551</vz810:BerichtCode>
			<xsl:apply-templates select="vz809:BerichtVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BerichtSubVersie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:AntwoordBetwistingDeclaratieReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BijlagenAantal" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BijlagenInformatie"/>
			
  	       	<vz810:Retourcodes>
					
				<xsl:copy-of select="$rc8028"/>
				<xsl:copy-of select="$rc8986"/>
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc8028='' and $rc8986=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
				
			</vz810:Retourcodes>
  	       	
		</vz810:Header>
	</xsl:template>
	
	<xsl:template match="vz809:BijlagenInformatie">	
		<vz810:BijlagenInformatie>
			<xsl:apply-templates select="vbt:BijlageNaam"/>
		</vz810:BijlagenInformatie>
	</xsl:template>

	<xsl:template match="vbt:BijlageNaam">	
		<vbt:BijlageNaam>
			<xsl:apply-templates select="vbt:Id" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:BijlageNaam>
	</xsl:template>	
	
	<xsl:template match="vz809:Context">
		<vz810:Context>
			
			<xsl:apply-templates select="vz809:DeclaratieReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:DeclaratieregelReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BetwistingDeclaratieReferentienummer" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:BetwistingDeclaratieregelReferentienummer" mode="copy-if-exists"/>
			
  	       	<vz810:Retourcodes>
				<!-- retourcode is altijd 0200 voor Context voor berichtcode 550 -->
					<vbt:Retourcode>0200</vbt:Retourcode>
			</vz810:Retourcodes>
  	       	
		</vz810:Context>
	</xsl:template>	
	
	<xsl:template match="vz809:Specificatieregel">
		<vz810:Specificatieregel>
			
			<xsl:apply-templates select="vz809:DebiteurOrgaan"/>
			<xsl:apply-templates select="vz809:Persoonsgegevens"/>
			<xsl:apply-templates select="vz809:Details"/>	
			
  	       	<vz810:Retourcodes>
				
				<!-- retourcode 0350: Geboortedatum moet kleiner zijn dan verzenddatum. -->
				<xsl:variable name="rc0350">
					<xsl:call-template name="rc0350">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>
						<xsl:with-param name="Geboortedatum" select="translate(vz809:Persoonsgegevens/vbt:Geboortedatum, '-', '')"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9196: Ten minste moet MedischeZorgkosten, Medicijnkosten, Tandartskosten, LangdurigeZorgkosten,  Ziekenhuisopnameskosten of OverigeKosten voorkomen. -->
				<xsl:variable name="rc9196">
					<xsl:variable name="AanvaardingBetwisting" select="vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting"/>
					<xsl:if test="($AanvaardingBetwisting !='')">
						<xsl:call-template name="rc9196">
							<xsl:with-param name="MedischeZorgkosten" select="vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting/vz809:Kosten/vbt:MedischeZorgkosten"/>
							<xsl:with-param name="Medicijnkosten" select="vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting/vz809:Kosten/vbt:Medicijnkosten"/>
							<xsl:with-param name="Tandartskosten" select="vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting/vz809:Kosten/vbt:Tandartskosten"/>
							<xsl:with-param name="LangdurigeZorgkosten" select="vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting/vz809:Kosten/vbt:LangdurigeZorgkosten"/>
							<xsl:with-param name="Ziekenhuisopnameskosten" select="vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting/vz809:Kosten/vbt:Ziekenhuisopnameskosten"/>
							<xsl:with-param name="OverigeKosten" select="vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting/vz809:Kosten/vbt:OverigeKosten"/>
						</xsl:call-template>
					</xsl:if>	
				</xsl:variable>
				
				<!-- retourcode 9203: DatumAntwoordBetwistingscode ontbreekt of is onjuist. -->
				<xsl:variable name="rc9203a">
					<xsl:call-template name="rc9203a">
						<xsl:with-param name="AntwoordBetwistingscode" select="$AntwoordBetwistingscode"/>	
						<xsl:with-param name="DatumAntwoordBetwistingscode" select="$DatumAntwoordBetwistingscode"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9204: Overig ontbreekt of is onjuist. -->
				<xsl:variable name="rc9204a">
					<xsl:call-template name="rc9204a">
						<xsl:with-param name="AntwoordBetwistingscode" select="$AntwoordBetwistingscode"/>	
						<xsl:with-param name="Overig" select="$Overig"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9205: AanvaardingBetwisting ontbreekt of is onjuist. -->
				<xsl:variable name="rc9205a">
					<xsl:call-template name="rc9205a">
						<xsl:with-param name="AntwoordBetwistingscode" select="$AntwoordBetwistingscode"/>	
						<xsl:with-param name="AanvaardingBetwisting" select="vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting"/>
					</xsl:call-template>
				</xsl:variable>
				
				<!-- retourcode 9207: Einddatum periode AanvaardingBetwisting moet gelijk zijn aan of later zijn dan de begindatum periode AanvaardingBetwisting -->
				<xsl:variable name="rc9207">
					<xsl:call-template name="rc9207">
						<xsl:with-param name="Begindatum" select="translate(vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting/vz809:Periode/vbt:Begindatum, '-', '')"/>	
						<xsl:with-param name="Einddatum" select="translate(vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting/vz809:Periode/vbt:Einddatum, '-', '')"/>						
					</xsl:call-template>
				</xsl:variable>				
				
				<!-- retourcode 9208: Einddatum periode AanvaardingBetwisting moet gelijk zijn aan of vroeger zijn dan de verzenddatum. -->
				<xsl:variable name="rc9208">
					<xsl:call-template name="rc9208">
						<xsl:with-param name="Verzenddatum" select="$Verzenddatum"/>	
						<xsl:with-param name="Einddatum" select="translate(vz809:Details/vz809:AanvullendeInfo/vz809:AanvaardingBetwisting/vz809:Periode/vbt:Einddatum, '-', '')"/>						
					</xsl:call-template>
				</xsl:variable>
				
				<xsl:copy-of select="$rc0350"/>
				<xsl:copy-of select="$rc9196"/>	
				<xsl:copy-of select="$rc9203a"/>
				<xsl:copy-of select="$rc9204a"/>
				<xsl:copy-of select="$rc9205a"/>
				<xsl:copy-of select="$rc9207"/>		
				<xsl:copy-of select="$rc9208"/>	
					
				<!-- Wanneer de klasse correct is dan wordt een 0200 retourcode toegevoegd. -->
				<xsl:if test="$rc0350='' and $rc9196=''and $rc9203a='' and $rc9204a='' and $rc9205a='' and $rc9207='' and $rc9208=''">
					<vbt:Retourcode>0200</vbt:Retourcode>
				</xsl:if>
				
			</vz810:Retourcodes>
  	       	
		</vz810:Specificatieregel>
	</xsl:template>		
	
	<xsl:template match="vbt:CrediteurOrgaan">	
		<vbt:CrediteurOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:CrediteurOrgaan>
	</xsl:template>
	
	<xsl:template match="vbt:BuitenlandsVerbindingsOrgaan">	
		<vbt:BuitenlandsVerbindingsOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vbt:BuitenlandsVerbindingsOrgaan>
	</xsl:template>

	<xsl:template match="vz809:DebiteurOrgaan">	
		<vz810:DebiteurOrgaan>
			<xsl:apply-templates select="vbt:Orgaancode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Landcode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Naam" mode="copy-if-exists"/>
		</vz810:DebiteurOrgaan>
	</xsl:template>

	<xsl:template match="vz809:Persoonsgegevens">	
		<vz810:Persoonsgegevens>
			<xsl:apply-templates select="vbt:PINVerzekeringsland" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:PINWoonlandofVerblijfsland" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Familienaam" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:FamilienaamGeboorte" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Voornamen" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:VoornamenGeboorte" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Geboortedatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:GeslachtCode" mode="copy-if-exists"/>
		</vz810:Persoonsgegevens>
	</xsl:template>		

	<xsl:template match="vz809:Details">	
		<vz810:Details>
			<xsl:apply-templates select="vz809:AntwoordBetwistingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:AanvullendeInfo"/>
			<xsl:apply-templates select="vz809:BedragAanvaardeBetwisting"/>
		</vz810:Details>
	</xsl:template>		

	<xsl:template match="vz809:AanvullendeInfo">	
		<vz810:AanvullendeInfo>
			<xsl:apply-templates select="vz809:DatumAntwoordBetwistingscode" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:Overig" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:AanvaardingBetwisting"/>
		</vz810:AanvullendeInfo>
	</xsl:template>	
	
	<xsl:template match="vz809:AanvaardingBetwisting">	
		<vz810:AanvaardingBetwisting>
			<xsl:apply-templates select="vz809:SoortPrestatie" mode="copy-if-exists"/>
			<xsl:apply-templates select="vz809:Periode"/>
			<xsl:apply-templates select="vz809:Kosten"/>
		</vz810:AanvaardingBetwisting>
	</xsl:template>		

	<xsl:template match="vz809:Periode">	
		<vz810:Periode>
			<xsl:apply-templates select="vbt:Begindatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Einddatum" mode="copy-if-exists"/>
		</vz810:Periode>
	</xsl:template>		
		
	<xsl:template match="vz809:Kosten">	
		<vz810:Kosten>
			<xsl:apply-templates select="vbt:MedischeZorgkosten"/>
			<xsl:apply-templates select="vbt:Medicijnkosten"/>
			<xsl:apply-templates select="vbt:Tandartskosten"/>
			<xsl:apply-templates select="vbt:LangdurigeZorgkosten"/>
			<xsl:apply-templates select="vbt:Ziekenhuisopnameskosten"/>
			<xsl:apply-templates select="vbt:OverigeKosten"/>
		</vz810:Kosten>
	</xsl:template>		

	<xsl:template match="vbt:MedischeZorgkosten">	
		<vbt:MedischeZorgkosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:MedischeZorgkosten>
	</xsl:template>	
	
	<xsl:template match="vbt:Medicijnkosten">	
		<vbt:Medicijnkosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:Medicijnkosten>
	</xsl:template>	
	
	<xsl:template match="vbt:Tandartskosten">	
		<vbt:Tandartskosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:Tandartskosten>
	</xsl:template>	
	
	<xsl:template match="vbt:LangdurigeZorgkosten">	
		<vbt:LangdurigeZorgkosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:LangdurigeZorgkosten>
	</xsl:template>	
	
	<xsl:template match="vbt:Periode">	
		<vbt:Periode>
			<xsl:apply-templates select="vbt:Begindatum" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Einddatum" mode="copy-if-exists"/>
		</vbt:Periode>
	</xsl:template>	
	
		<xsl:template match="vbt:Ziekenhuisopnameskosten">	
		<vbt:Ziekenhuisopnameskosten>
			<xsl:apply-templates select="vbt:UitkeringZiekenhuisopname"/>
		</vbt:Ziekenhuisopnameskosten>
	</xsl:template>

	<xsl:template match="vbt:UitkeringZiekenhuisopname">	
		<vbt:UitkeringZiekenhuisopname>
			<xsl:apply-templates select="vbt:Periode"/>
			<xsl:apply-templates select="vbt:Kosten"/>
		</vbt:UitkeringZiekenhuisopname>
	</xsl:template>		
	
	<xsl:template match="vbt:Kosten">	
		<vbt:Kosten>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
		</vbt:Kosten>
	</xsl:template>	

		<xsl:template match="vbt:OverigeKosten">	
		<vbt:OverigeKosten>
			<xsl:apply-templates select="vbt:UitkeringOverig"/>
		</vbt:OverigeKosten>
	</xsl:template>

	<xsl:template match="vbt:UitkeringOverig">	
		<vbt:UitkeringOverig>
			<xsl:apply-templates select="vbt:Beschrijving" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Kosten"/>
		</vbt:UitkeringOverig>
	</xsl:template>	

	<xsl:template match="vz809:BedragAanvaardeBetwisting">	
		<vz810:BedragAanvaardeBetwisting>
			<xsl:apply-templates select="vbt:Bedrag" mode="copy-if-exists"/>
			<xsl:apply-templates select="vbt:Valuta" mode="copy-if-exists"/>
		</vz810:BedragAanvaardeBetwisting>
	</xsl:template>			
	
	<!-- Copy template: als een enkel element voorkomt is, wordt deze gekopieerd in de opgegeven namespace -->
	<xsl:template match="vz809:*" mode="copy-if-exists">
		<xsl:param name="NameSpacePrefix" select="'vz810:'"/>
		<xsl:if test=".">
			<xsl:element name="{concat($NameSpacePrefix,local-name())}">
				<xsl:value-of select="text()"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="*[not(starts-with(name(), 'vz809:'))]" mode="copy-if-exists">
        <xsl:if test=".">
            <xsl:element name="{name()}">
				<xsl:value-of select="text()"/>
            </xsl:element>
        </xsl:if>
	</xsl:template>

</xsl:stylesheet>